#[non_exhaustive]pub struct Config {
pub test: Option<TestConfig>,
pub ignore: Option<Vec<String>>,
pub packages: Option<HashMap<String, PackageConfig>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.test: Option<TestConfig>ignore: Option<Vec<String>>packages: Option<HashMap<String, PackageConfig>>Implementations
Sourceimpl Config
impl Config
Sourcepub fn load(root: &Path) -> Result<Self>
pub fn load(root: &Path) -> Result<Self>
Load config from .affected.toml in the project root, or return defaults.
Sourcepub fn load_from(path: &Path) -> Result<Self>
pub fn load_from(path: &Path) -> Result<Self>
Load config from a specific path (for –config flag).
Sourcepub fn package_config(&self, name: &str) -> Option<&PackageConfig>
pub fn package_config(&self, name: &str) -> Option<&PackageConfig>
Get per-package configuration by name.
Sourcepub fn test_command_for(
&self,
ecosystem: Ecosystem,
package: &str,
) -> Option<Vec<String>>
pub fn test_command_for( &self, ecosystem: Ecosystem, package: &str, ) -> Option<Vec<String>>
Get a custom test command for a given ecosystem and package.
Replaces {package} placeholder with the actual package name.
Sourcepub fn is_ignored(&self, path: &str) -> bool
pub fn is_ignored(&self, path: &str) -> bool
Check if a file path matches any ignore patterns.