pub fn find_affected(root: &Path, base_ref: &str) -> Result<AffectedResult>Expand description
Main orchestration: given a project root and base ref, determine which packages are affected by git changes.
pub fn find_affected(root: &Path, base_ref: &str) -> Result<AffectedResult>Main orchestration: given a project root and base ref, determine which packages are affected by git changes.